@@ -6,7 +6,7 @@ import sys
 from django.conf import settings
 from django.conf.urls.defaults import *
 
-VERSION = (0, 5, 0, 'final')
+VERSION = (0, 6, 0, 'final')
 
 def get_version():
     version = '%s.%s' % (VERSION[0], VERSION[1])
@@ -21,9 +21,8 @@ def dependency_found(addon):
         getattr(settings, "ADDONS", []) + 
         getattr(settings, "ADDONS_PROVIDED", []))
 
-def get_meta(addon):
+def get_meta(name):
     # Load metainformation
-    name = "%s.%s" % (settings.ADDONS_PREFIX, addon)
     try:
         mod = None
         __import__(name)
