@@ -7,7 +7,7 @@ def autodiscover_handlers():
     Register signal handlers from each addon.
     """
     for addon in settings.ADDONS:
-        fullname = "%s.%s.handlers" % (settings.ADDONS_PREFIX, addon)
+        fullname = "%s.handlers" % addon
         try:
             __import__(fullname)
         except ImportError, err:
@@ -24,7 +24,7 @@ def autodiscover_notifications():
     TODO: Implement this with signals. Requires changes in django-notifications upstream.
     """
     for addon in settings.ADDONS:
-        fullname = "%s.%s.notifications" % (settings.ADDONS_PREFIX, addon)
+        fullname = "%s.notifications" % addon
         try:
             __import__(fullname)
         except ImportError:
