@@ -1,9 +1,9 @@
 # -*- coding: utf-8 -*-
 import re
 from django import template
+from django.conf import settings
 from django.template import Node, Variable, TemplateSyntaxError, TemplateDoesNotExist
 from django.template.loader import get_template_from_string, find_template_source
-import settings
 from django.template.loader_tags import BlockNode
 
 """
