@@ -21,8 +21,14 @@ if settings.DEBUG:
     urlpatterns += patterns('', url(r'^addons/$', addons_view))
 
 for addon in settings.ADDONS:
-    filename = "%s/%s/urls.py" % (settings.ADDONS_ROOT, addon)
-    fullname = "%s.%s.urls" % (settings.ADDONS_PREFIX, addon)
+    addon_dir = None
+    for ADDONS_ROOT in settings.ADDONS_ROOTS:
+        addon_dir = "%s/%s" % (ADDONS_ROOT, addon)
+        if os.path.exists(addon_dir):
+            break
+
+    filename = "%s/urls.py" % (addon_dir)
+    fullname = "%s.urls" % addon
     if os.path.exists(filename):
         urlpatterns += patterns('',
             url(r'', include(fullname)),
