@@ -11,12 +11,12 @@ from django_addons import get_meta
 def addons_view(request):
     addons = {}
     for addon in settings.ADDONS:
-        print "%s.%s" % (settings.ADDONS_PREFIX, addon),
+        print addon
         addons[addon] = dict()
         addons[addon]["meta"] = get_meta(addon)
         addons[addon]["enabled"] = True
         
-        m = "%s.%s.models" % (settings.ADDONS_PREFIX, addon)
+        m = "%s.models" % addon
         for app in models.get_apps():
             if m == app.__name__:
                 addons[addon]["models_loaded"] = True
